@@ -1,13 +1,12 @@
+use crate::{
+    css_attributes, syntax_error, AnchorPoint, CssAttribute, NeverArbitrary, Result, TailwindArbitrary, TailwindBuilder,
+    TailwindColor, TailwindInstance,
+};
 use std::{
     collections::BTreeSet,
     fmt::{Debug, Display, Formatter},
 };
 
-use crate::{
-    css_attributes, syntax_error, AnchorPoint, CssAttribute, Result, TailwindArbitrary, TailwindBuilder, TailwindColor,
-    TailwindInstance,
-};
-
 pub use self::{
     attachment::TailwindBackgroundAttachment,
     clip::TailwindBackgroundClip,
