@@ -199,9 +199,8 @@ impl TailwindInstruction {
     fn bg_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/background-attachment
-            ["fixed"] => TailwindBackgroundAttachment::Fixed.boxed(),
-            ["local"] => TailwindBackgroundAttachment::Local.boxed(),
-            ["scroll"] => TailwindBackgroundAttachment::Scroll.boxed(),
+            [s @ ("fixed" | "local" | "scroll")] => TailwindBackgroundAttachment::from(*s).boxed(),
+            ["attach", rest @ ..] => TailwindBackgroundAttachment::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/background-clip
             ["clip", "border"] => TailwindBackgroundClip::from("border-box").boxed(),
             ["clip", "padding"] => TailwindBackgroundClip::from("padding-box").boxed(),
